@@ -61,6 +61,8 @@ async def get_query_from_db(query , table_to_backup , env_file_name = None , par
         conn = await engine_manager.connect_db(env_file_name)
         await backup_table(table_to_backup, conn)
         query_output = await conn.execute(text(query) , params)
+        if not query_output.returns_rows:
+            return None
         return await format_to_df(query_output)
     except sqlalchemy.exc.SQLAlchemyError as e:
         logger.error(f"Failed to execute query:\n{e}")
@@ -90,6 +92,8 @@ async def exec_procedure_from_db(procedure_name , table_to_backup , env_file_nam
         await backup_table(table_to_backup, conn)
         params_string = build_procedure_param_string(params)
         procedure_output = await conn.execute(text(f"EXEC {procedure_name} {params_string}"), params)
+        if not procedure_output.returns_rows:
+            return None
         return await format_to_df(procedure_output)
     except sqlalchemy.exc.SQLAlchemyError as e:
         logger.error(f"Failed to execute procedure:\n{e}")
@@ -134,8 +138,8 @@ async def backup_table(table_to_backup , conn):
 
         backup_query = f"SELECT * FROM {table_to_backup}"
         result = await conn.execute(text(backup_query))
-        rows = await result.fetchall()
-        columns = await result.keys()
+        rows = result.fetchall()
+        columns = result.keys()
         backup_df = pd.DataFrame(rows, columns=columns)
         backup_filename = os.path.join(backup_dir_name, f"{table_to_backup}_backup_{datetime.now().strftime('%Y-%m-%d_%H-%M-%S')}.md")
 
